import { __assign } from "tslib";
/**
 * Load config for Cypress from environment variables. Loads
 * FIREBASE_AUTH_EMULATOR_HOST, FIRESTORE_EMULATOR_HOST,
 * FIREBASE_DATABASE_EMULATOR_HOST, and GCLOUD_PROJECT variable
 * values from environment to pass to Cypress environment
 * @param cypressConfig - Existing Cypress config
 * @returns Cypress config extended with environment variables
 */
export default function extendWithFirebaseConfig(cypressConfig) {
    var valuesFromEnv = [
        'FIREBASE_AUTH_EMULATOR_HOST',
        'FIREBASE_DATABASE_EMULATOR_HOST',
        'FIRESTORE_EMULATOR_HOST',
        'GCLOUD_PROJECT',
    ].reduce(function (acc, varKey) {
        var _a;
        return process.env[varKey] ? __assign(__assign({}, acc), (_a = {}, _a[varKey] = process.env[varKey], _a)) : acc;
    }, {});
    // Return merge with original config (so it is not runover)
    return __assign(__assign({}, cypressConfig), { env: __assign(__assign({}, valuesFromEnv), cypressConfig === null || cypressConfig === void 0 ? void 0 : cypressConfig.env) });
}
