import extendWithFirebaseConfig from './extendWithFirebaseConfig';
import * as tasks from './tasks';
import { initializeFirebase } from './firebase-utils';
/**
 * @param cypressOnFunc - on function from cypress plugins file
 * @param cypressConfig - Cypress config
 * @param adminInstance - firebase-admin instance
 * @param overrideConfig - Override config for firebase instance
 * @returns Extended Cypress config
 */
export default function pluginWithTasks(cypressOnFunc, cypressConfig, adminInstance, overrideConfig) {
    var _a;
    // Only initialize admin instance if it hasn't already been initialized
    if (((_a = adminInstance.apps) === null || _a === void 0 ? void 0 : _a.length) === 0) {
        initializeFirebase(adminInstance, overrideConfig);
    }
    // Parse single argument from task into arguments for task methods while
    // also passing the admin instance
    var tasksWithFirebase = {};
    Object.keys(tasks).forEach(function (taskName) {
        tasksWithFirebase[taskName] = function (taskSettings) {
            if (taskSettings === null || taskSettings === void 0 ? void 0 : taskSettings.uid) {
                return tasks[taskName](adminInstance, taskSettings.uid, taskSettings);
            }
            var action = taskSettings.action, actionPath = taskSettings.path, _a = taskSettings.options, options = _a === void 0 ? {} : _a, data = taskSettings.data;
            return tasks[taskName](adminInstance, action, actionPath, options, data);
        };
    });
    // Attach tasks to Cypress using on function
    cypressOnFunc('task', tasksWithFirebase);
    // Return extended config
    return extendWithFirebaseConfig(cypressConfig);
}
